==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=cpf
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Group-la lé kosékan :</b> akoz sa minm, ni konsèy aou swazi inn moklalé dann group-la.

',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Bann komandèr-sitwèb',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Bann lotèr',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'bann vizitèr lo sit piblik kank zot i espédi inn modékri si inn forom.

',

	// I
	'icone_creation_groupe_mots' => 'Kré inn nouvo group astèr pou bann molaklé',
	'icone_creation_mots_cles' => 'Kré inn nouvo molaklé',
	'icone_modif_groupe_mots' => 'Sanz lo group bann mo-la',
	'icone_mots_cles' => 'Bann molaklé',
	'icone_supprimer_groupe_mots' => 'Dégrèn group-la',
	'icone_voir_tous_mots_cles' => 'Vwar tout bann molaklé',
	'info_articles_lies_mot' => 'Bann zartik an gatiraz èk molaklé-la',
	'info_changer_nom_groupe' => 'Sanz lo non lansanm-la :',
	'info_creation_mots_cles' => 'Kré èk konfigir tèrla tout bann molaklé lo sit',
	'info_dans_groupe' => 'Dann group-la :',
	'info_delet_mots_cles' => 'Ou la finn
domann dégrèn molaklé-la
<b>@titre_mot@</b> (@type_mot@). Kom li lé gatiré èk
<b>@texte_lie@</b> ou i dwa konfirm sak i vé :', # MODIF
	'info_groupe_important' => 'Group larz',
	'info_mots_cles' => 'Bann molaklé',
	'info_mots_cles_association' => 'I pé mèt ansanm bann molaklé lo group-la :',
	'info_oui_suppression_mot_cle' => 'Mi vé dégrèn molaklé-la.',
	'info_question_mots_cles' => 'Anserv bann molaklé sir out sitwèb ?',
	'info_qui_attribue_mot_cle' => 'Lo moun-la i pé mèt bann molaklé dann group-la :',
	'info_retirer_mot' => 'Anlèv mo-la',
	'info_retirer_mots' => 'Anlèv tout bann mo',
	'info_rubriques_liees_mot' => 'Bann rubrik-la lé gatiré èk molaklé-la',
	'info_selection_un_seul_mot_cle' => 'Lé posib swazi <b>selman inn molaklé</b> an inn fwa dann group-la.', # MODIF
	'info_supprimer_mot' => 'dégrèn mo la',
	'info_titre_mot_cle' => 'Non ou titr lo molaklé',
	'info_un_mot' => 'En sel mo a lafwa',
	'item_ajout_mots_cles' => 'Permèt azouté bann molaklé dann bann forom',
	'item_non_ajout_mots_cles' => 'Anpès ansèrv bann molaklé dann bann forom',
	'item_non_utiliser_config_groupe_mots_cles' => 'Anserv pa lakonfigirasyon présiz pou bann group molaklé',
	'item_non_utiliser_mots_cles' => 'Anpès ansèrv bann molaklé',
	'item_utiliser_config_groupe_mots_cles' => 'Anserv lakonfigirasyon présiz pour bann group molaklé.',
	'item_utiliser_mots_cles' => 'Ansèrv bann molaklé',

	// L
	'logo_mot_cle' => 'LOGO MOLAKLÉ-LA',

	// T
	'texte_config_groupe_mots_cles' => 'Ou vé fé zwé astèr lakonfigirasyon présiz pou bann molaklé ? 
Li pé permèt alor swazi inn  sèl molaklé sanm group, o rand inn group pli importan, é tousala... ', # MODIF
	'texte_mots_cles' => 'Bann molaklé i permèt aou kré bann gatiraz antrobann zartik, sélon lo tèm zot i abord. Bann gatiraz-la lé indépandan laplas bann zartik dann rubrik. Ou i pé anserv azot pou rand lo batkaraz pli ris sir out sitwèb, o pou rand pli personèl laprézantasyon out bann skelèt.',
	'texte_mots_cles_dans_forum' => 'Indik isi si ou vé permèt litilizasyon bann molaklé, sak bann vizitèr i pé swazi zot-minm, dann bann forom piblik sir lo sitwèb ? (Tansyon pangar :lopsyon-la lé inn pé difisil pou anserv é pou fé zwé byin korèkman.)',
	'texte_nouveau_mot' => 'Nouvo mo',
	'titre_config_groupe_mots_cles' => 'Lakonfigirasyon pou bann group molaklé',
	'titre_gauche_mots_edit' => 'MO NIMÉRO :',
	'titre_mots_cles_dans_forum' => 'Bann molaklé dann bann forom sir figirwèb',
	'titre_mots_tous' => 'Bann molaklé',
	'titre_nouveau_groupe' => 'Nouvo group',
	'titre_page_mots_tous' => 'Bann molaklé'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=cpf
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Group-la lé kosékan :</b> akoz sa minm, ni konsèy aou swazi inn moklalé dann group-la.

',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Bann komandèr-sitwèb',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Bann lotèr',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'bann vizitèr lo sit piblik kank zot i espédi inn modékri si inn forom.

',

	// I
	'icone_creation_groupe_mots' => 'Kré inn nouvo group astèr pou bann molaklé',
	'icone_creation_mots_cles' => 'Kré inn nouvo molaklé',
	'icone_modif_groupe_mots' => 'Sanz lo group bann mo-la',
	'icone_mots_cles' => 'Bann molaklé',
	'icone_supprimer_groupe_mots' => 'Dégrèn group-la',
	'icone_voir_tous_mots_cles' => 'Vwar tout bann molaklé',
	'info_articles_lies_mot' => 'Bann zartik an gatiraz èk molaklé-la',
	'info_changer_nom_groupe' => 'Sanz lo non lansanm-la :',
	'info_creation_mots_cles' => 'Kré èk konfigir tèrla tout bann molaklé lo sit',
	'info_dans_groupe' => 'Dann group-la :',
	'info_delet_mots_cles' => 'Ou la finn
domann dégrèn molaklé-la
<b>@titre_mot@</b> (@type_mot@). Kom li lé gatiré èk
<b>@texte_lie@</b> ou i dwa konfirm sak i vé :', # MODIF
	'info_groupe_important' => 'Group larz',
	'info_mots_cles' => 'Bann molaklé',
	'info_mots_cles_association' => 'I pé mèt ansanm bann molaklé lo group-la :',
	'info_oui_suppression_mot_cle' => 'Mi vé dégrèn molaklé-la.',
	'info_question_mots_cles' => 'Anserv bann molaklé sir out sitwèb ?',
	'info_qui_attribue_mot_cle' => 'Lo moun-la i pé mèt bann molaklé dann group-la :',
	'info_retirer_mot' => 'Anlèv mo-la',
	'info_retirer_mots' => 'Anlèv tout bann mo',
	'info_rubriques_liees_mot' => 'Bann rubrik-la lé gatiré èk molaklé-la',
	'info_selection_un_seul_mot_cle' => 'Lé posib swazi <b>selman inn molaklé</b> an inn fwa dann group-la.', # MODIF
	'info_supprimer_mot' => 'dégrèn mo la',
	'info_titre_mot_cle' => 'Non ou titr lo molaklé',
	'info_un_mot' => 'En sel mo a lafwa',
	'item_ajout_mots_cles' => 'Permèt azouté bann molaklé dann bann forom',
	'item_non_ajout_mots_cles' => 'Anpès ansèrv bann molaklé dann bann forom',
	'item_non_utiliser_config_groupe_mots_cles' => 'Anserv pa lakonfigirasyon présiz pou bann group molaklé',
	'item_non_utiliser_mots_cles' => 'Anpès ansèrv bann molaklé',
	'item_utiliser_config_groupe_mots_cles' => 'Anserv lakonfigirasyon présiz pour bann group molaklé.',
	'item_utiliser_mots_cles' => 'Ansèrv bann molaklé',

	// L
	'logo_mot_cle' => 'LOGO MOLAKLÉ-LA',

	// T
	'texte_config_groupe_mots_cles' => 'Ou vé fé zwé astèr lakonfigirasyon présiz pou bann molaklé ? 
Li pé permèt alor swazi inn  sèl molaklé sanm group, o rand inn group pli importan, é tousala... ', # MODIF
	'texte_mots_cles' => 'Bann molaklé i permèt aou kré bann gatiraz antrobann zartik, sélon lo tèm zot i abord. Bann gatiraz-la lé indépandan laplas bann zartik dann rubrik. Ou i pé anserv azot pou rand lo batkaraz pli ris sir out sitwèb, o pou rand pli personèl laprézantasyon out bann skelèt.',
	'texte_mots_cles_dans_forum' => 'Indik isi si ou vé permèt litilizasyon bann molaklé, sak bann vizitèr i pé swazi zot-minm, dann bann forom piblik sir lo sitwèb ? (Tansyon pangar :lopsyon-la lé inn pé difisil pou anserv é pou fé zwé byin korèkman.)',
	'texte_nouveau_mot' => 'Nouvo mo',
	'titre_config_groupe_mots_cles' => 'Lakonfigirasyon pou bann group molaklé',
	'titre_gauche_mots_edit' => 'MO NIMÉRO :',
	'titre_mots_cles_dans_forum' => 'Bann molaklé dann bann forom sir figirwèb',
	'titre_mots_tous' => 'Bann molaklé',
	'titre_nouveau_groupe' => 'Nouvo group',
	'titre_page_mots_tous' => 'Bann molaklé',
];
